/*
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://www.eu-egee.org/partners/ for details on the copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *  gLite Data Management - Simple channel management API
 *
 *  Authors:
 *      Zsolt Molnar <Zsolt.Molnar@cern.ch>
 */

#include <stdlib.h>
#include <assert.h>

#include "../fts_exception.h"

struct fts_exception
{
	const axutil_env_t *env;
	fts_exception_id_t id;
	void *obj;
	_fts_exception_freefv_t freefv;
	_fts_exception_get_messagefv_t messagefv;
	_fts_exception_get_namefv_t namefv;
	_fts_exception_get_glite_transfer_errclassfv errclassfv;
};

fts_exception_t* fts_exception_create(const axutil_env_t *env, const fts_exception_id_t id,
		void* obj, _fts_exception_freefv_t freefv, _fts_exception_get_messagefv_t messagefv,
		_fts_exception_get_namefv_t namefv, _fts_exception_get_glite_transfer_errclassfv errclassfv)
{
	assert(env);
	assert(obj);
	assert(freefv);
	assert(messagefv);
	assert(namefv);
	assert(errclassfv);

	fts_exception_t* self = calloc(1, sizeof(fts_exception_t));
	assert(self);

	if (self) {
		self->env = env;
		self->id = id;
		self->obj = obj;
		self->freefv = freefv;
		self->messagefv = messagefv;
		self->namefv = namefv;
		self->errclassfv = errclassfv;
	}

	return self;
}

void fts_exception_free(fts_exception_t *self)
{
	assert(self);

	if (self) {
		assert(self->freefv);
		self->freefv(self);
		free(self);
	}
}

fts_exception_id_t fts_exception_get_id(const fts_exception_t *self)
{
	assert(self);
	return self ? self->id : fts_exception_Unknown_id;
}

void* fts_exception_get_object(const fts_exception_t* self)
{
	assert(self);
	return self ? self->obj : NULL;
}

const char* fts_exception_get_message(const fts_exception_t* self)
{
	assert(self);
	assert(self->messagefv);
	return self && self->messagefv ? self->messagefv(self) : NULL;
}

const char* fts_exception_get_name(const fts_exception_t* self)
{
	assert(self);
	assert(self->namefv);
	return self && self->namefv ? self->namefv() : NULL;
}

const axutil_env_t* fts_exception_get_env(const fts_exception_t* self)
{
	assert(self);
	return self->env;
}

glite_transfer_errclass fts_exception_get_glite_transfer_errclass(const fts_exception_t* self)
{
	assert(self);
	assert(self->errclassfv);
	return self->errclassfv();
}
