/*
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://www.eu-egee.org/partners/ for details on the copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *  gLite Data Management - Simple channel management API
 *
 *  Authors:
 *      Zsolt Molnar <Zsolt.Molnar@cern.ch>
 */

#ifndef FTS_EXCEPTION_FACTORY_H
#define FTS_EXCEPTION_FACTORY_H
 
#include <axutil_env.h>

#include "../fts_exception.h"
#include "fts_xml_repr.h"

/**
 * Create and deserialize the adb_Authorization object out of its
 * XML representation.
 * @param detail The "detail" node/element pair, represented as internal AXIOM
 *               tree. This element is the parent of the WSDL fault, and the
 *               adb_Authorization_deserialize can process it.
 * @param env The present AXIS environment.
 * @return The exception object as void pointer, its ID and a function that is
 *         able to free the memory of the object. NULL in case of processing error
 *         or if detail does not encode an adb_Authorization type.
 */
fts_exception_t* _fts_create_exception_Authorization(fts_xml_repr_t *detail, const axutil_env_t *env);

/**
 * Free an adb_Authorization_t object
 * @param self The object to be freed.
 */
void _fts_exception_free_Authorization(fts_exception_t *self);

/**
 * Return the message data of a Authorization object.
 * @param self The object.
 * @return The message or NULL in case of error/nill-ness.
 */
const char* _fts_exception_get_message_Authorization(const fts_exception_t *self);

/**
 * Return "Authorization".
 */
const char* _fts_exception_get_name_Authorization(void);

/**
 * Map the exception to a glite_transfer_errclass.
 *
 */
glite_transfer_errclass _fts_exception_get_glite_transfer_errclass_Authorization(void);
/**
 * Create and deserialize the adb_Internal object out of its
 * XML representation.
 * @param detail The "detail" node/element pair, represented as internal AXIOM
 *               tree. This element is the parent of the WSDL fault, and the
 *               adb_Internal_deserialize can process it.
 * @param env The present AXIS environment.
 * @return The exception object as void pointer, its ID and a function that is
 *         able to free the memory of the object. NULL in case of processing error
 *         or if detail does not encode an adb_Internal type.
 */
fts_exception_t* _fts_create_exception_Internal(fts_xml_repr_t *detail, const axutil_env_t *env);

/**
 * Free an adb_Internal_t object
 * @param self The object to be freed.
 */
void _fts_exception_free_Internal(fts_exception_t *self);

/**
 * Return the message data of a Internal object.
 * @param self The object.
 * @return The message or NULL in case of error/nill-ness.
 */
const char* _fts_exception_get_message_Internal(const fts_exception_t *self);

/**
 * Return "Internal".
 */
const char* _fts_exception_get_name_Internal(void);

/**
 * Map the exception to a glite_transfer_errclass.
 *
 */
glite_transfer_errclass _fts_exception_get_glite_transfer_errclass_Internal(void);
/**
 * Create and deserialize the adb_NotExists object out of its
 * XML representation.
 * @param detail The "detail" node/element pair, represented as internal AXIOM
 *               tree. This element is the parent of the WSDL fault, and the
 *               adb_NotExists_deserialize can process it.
 * @param env The present AXIS environment.
 * @return The exception object as void pointer, its ID and a function that is
 *         able to free the memory of the object. NULL in case of processing error
 *         or if detail does not encode an adb_NotExists type.
 */
fts_exception_t* _fts_create_exception_NotExists(fts_xml_repr_t *detail, const axutil_env_t *env);

/**
 * Free an adb_NotExists_t object
 * @param self The object to be freed.
 */
void _fts_exception_free_NotExists(fts_exception_t *self);

/**
 * Return the message data of a NotExists object.
 * @param self The object.
 * @return The message or NULL in case of error/nill-ness.
 */
const char* _fts_exception_get_message_NotExists(const fts_exception_t *self);

/**
 * Return "NotExists".
 */
const char* _fts_exception_get_name_NotExists(void);

/**
 * Map the exception to a glite_transfer_errclass.
 *
 */
glite_transfer_errclass _fts_exception_get_glite_transfer_errclass_NotExists(void);
/**
 * Create and deserialize the adb_InvalidArgument object out of its
 * XML representation.
 * @param detail The "detail" node/element pair, represented as internal AXIOM
 *               tree. This element is the parent of the WSDL fault, and the
 *               adb_InvalidArgument_deserialize can process it.
 * @param env The present AXIS environment.
 * @return The exception object as void pointer, its ID and a function that is
 *         able to free the memory of the object. NULL in case of processing error
 *         or if detail does not encode an adb_InvalidArgument type.
 */
fts_exception_t* _fts_create_exception_InvalidArgument(fts_xml_repr_t *detail, const axutil_env_t *env);

/**
 * Free an adb_InvalidArgument_t object
 * @param self The object to be freed.
 */
void _fts_exception_free_InvalidArgument(fts_exception_t *self);

/**
 * Return the message data of a InvalidArgument object.
 * @param self The object.
 * @return The message or NULL in case of error/nill-ness.
 */
const char* _fts_exception_get_message_InvalidArgument(const fts_exception_t *self);

/**
 * Return "InvalidArgument".
 */
const char* _fts_exception_get_name_InvalidArgument(void);

/**
 * Map the exception to a glite_transfer_errclass.
 *
 */
glite_transfer_errclass _fts_exception_get_glite_transfer_errclass_InvalidArgument(void);
/**
 * Create and deserialize the adb_ServiceBusy object out of its
 * XML representation.
 * @param detail The "detail" node/element pair, represented as internal AXIOM
 *               tree. This element is the parent of the WSDL fault, and the
 *               adb_ServiceBusy_deserialize can process it.
 * @param env The present AXIS environment.
 * @return The exception object as void pointer, its ID and a function that is
 *         able to free the memory of the object. NULL in case of processing error
 *         or if detail does not encode an adb_ServiceBusy type.
 */
fts_exception_t* _fts_create_exception_ServiceBusy(fts_xml_repr_t *detail, const axutil_env_t *env);

/**
 * Free an adb_ServiceBusy_t object
 * @param self The object to be freed.
 */
void _fts_exception_free_ServiceBusy(fts_exception_t *self);

/**
 * Return the message data of a ServiceBusy object.
 * @param self The object.
 * @return The message or NULL in case of error/nill-ness.
 */
const char* _fts_exception_get_message_ServiceBusy(const fts_exception_t *self);

/**
 * Return "ServiceBusy".
 */
const char* _fts_exception_get_name_ServiceBusy(void);

/**
 * Map the exception to a glite_transfer_errclass.
 *
 */
glite_transfer_errclass _fts_exception_get_glite_transfer_errclass_ServiceBusy(void);
/**
 * Create and deserialize the adb_CannotCancel object out of its
 * XML representation.
 * @param detail The "detail" node/element pair, represented as internal AXIOM
 *               tree. This element is the parent of the WSDL fault, and the
 *               adb_CannotCancel_deserialize can process it.
 * @param env The present AXIS environment.
 * @return The exception object as void pointer, its ID and a function that is
 *         able to free the memory of the object. NULL in case of processing error
 *         or if detail does not encode an adb_CannotCancel type.
 */
fts_exception_t* _fts_create_exception_CannotCancel(fts_xml_repr_t *detail, const axutil_env_t *env);

/**
 * Free an adb_CannotCancel_t object
 * @param self The object to be freed.
 */
void _fts_exception_free_CannotCancel(fts_exception_t *self);

/**
 * Return the message data of a CannotCancel object.
 * @param self The object.
 * @return The message or NULL in case of error/nill-ness.
 */
const char* _fts_exception_get_message_CannotCancel(const fts_exception_t *self);

/**
 * Return "CannotCancel".
 */
const char* _fts_exception_get_name_CannotCancel(void);

/**
 * Map the exception to a glite_transfer_errclass.
 *
 */
glite_transfer_errclass _fts_exception_get_glite_transfer_errclass_CannotCancel(void);
/**
 * Create and deserialize the adb_Exists object out of its
 * XML representation.
 * @param detail The "detail" node/element pair, represented as internal AXIOM
 *               tree. This element is the parent of the WSDL fault, and the
 *               adb_Exists_deserialize can process it.
 * @param env The present AXIS environment.
 * @return The exception object as void pointer, its ID and a function that is
 *         able to free the memory of the object. NULL in case of processing error
 *         or if detail does not encode an adb_Exists type.
 */
fts_exception_t* _fts_create_exception_Exists(fts_xml_repr_t *detail, const axutil_env_t *env);

/**
 * Free an adb_Exists_t object
 * @param self The object to be freed.
 */
void _fts_exception_free_Exists(fts_exception_t *self);

/**
 * Return the message data of a Exists object.
 * @param self The object.
 * @return The message or NULL in case of error/nill-ness.
 */
const char* _fts_exception_get_message_Exists(const fts_exception_t *self);

/**
 * Return "Exists".
 */
const char* _fts_exception_get_name_Exists(void);

/**
 * Map the exception to a glite_transfer_errclass.
 *
 */
glite_transfer_errclass _fts_exception_get_glite_transfer_errclass_Exists(void);

#endif /* #ifndef FTS_EXCEPTION_FACTORY_H */
