/*
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://www.eu-egee.org/partners/ for details on the copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *  gLite Data Management - Simple channel management API
 *
 *  Authors:
 *      Zsolt Molnar <Zsolt.Molnar@cern.ch>
 */

#include "../../axis/adb_ExistsException.h"
#include "fts_soap_exception_api_impl.h"
#include "fts_exception_factory.h"

fts_exception_t* _fts_create_exception_ExistsException(fts_xml_repr_t *detail, const axutil_env_t *env)
{
    fts_exception_t *exception = NULL;
    fts_xml_repr_t *exception_xml = _fts_get_exception_xml("ExistsException", env, detail);

    if (exception_xml) {
        axis2_status_t deserialize_status = AXIS2_FAILURE;
        adb_ExistsException_t *obj = adb_ExistsException_create(env);
        assert(obj);

        if (obj)
            deserialize_status = adb_ExistsException_deserialize(
                    obj, env, fts_xml_repr_node_ref(exception_xml), NULL, AXIS2_FALSE);

        if (deserialize_status == AXIS2_SUCCESS)
            exception = fts_exception_create(env, fts_exception_ExistsException_id, obj, 
                _fts_exception_free_ExistsException, _fts_exception_get_message_ExistsException,
                _fts_exception_get_name_ExistsException);
    }

    fts_xml_repr_free(exception_xml, env);
    return exception;
}

void _fts_exception_free_ExistsException(fts_exception_t *self)
{
    assert(self);
    const axutil_env_t *env = fts_exception_get_env(self);
    assert(env);
    
    if (self && env) {
        adb_ExistsException_t* obj = (adb_ExistsException_t*)(fts_exception_get_object(self));
        adb_ExistsException_free(obj, env);
    }
}

const char* _fts_exception_get_message_ExistsException(const fts_exception_t *self)
{
    assert(self);
    const axutil_env_t *env = fts_exception_get_env(self);
    adb_ExistsException_t* obj = (adb_ExistsException_t*)(fts_exception_get_object(self));
    assert(env);
    assert(obj);
    const char* message = NULL;
    
    if (self && obj && env) {
        adb_TExistsException_t* real_object = adb_ExistsException_get_ExistsException(obj, env);
        assert(real_object);
        
        if (real_object && 
            !adb_TExistsException_is_message_nil(real_object, env))
        {
            message = adb_TExistsException_get_message(real_object, env);
        }
    }

    return message;    
}

const char* _fts_exception_get_name_ExistsException(void)
{
    return "ExistsException";
}

