/*
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://www.eu-egee.org/partners/ for details on the copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *  gLite Data Management - Simple channel management API
 *
 *  Authors:
 *      Zsolt Molnar <Zsolt.Molnar@cern.ch>
 */

#include "../../axis/adb_NotExistsException.h"
#include "fts_soap_exception_api_impl.h"
#include "fts_exception_factory.h"

fts_exception_t* _fts_create_exception_NotExistsException(fts_xml_repr_t *detail, const axutil_env_t *env)
{
    fts_exception_t *exception = NULL;
    fts_xml_repr_t *exception_xml = _fts_get_exception_xml("NotExistsException", env, detail);

    if (exception_xml) {
        axis2_status_t deserialize_status = AXIS2_FAILURE;
        adb_NotExistsException_t *obj = adb_NotExistsException_create(env);
        assert(obj);

        if (obj)
            deserialize_status = adb_NotExistsException_deserialize(
                    obj, env, fts_xml_repr_node_ref(exception_xml), NULL, AXIS2_FALSE);

        if (deserialize_status == AXIS2_SUCCESS)
            exception = fts_exception_create(env, fts_exception_NotExistsException_id, obj, 
                _fts_exception_free_NotExistsException, _fts_exception_get_message_NotExistsException,
                _fts_exception_get_name_NotExistsException);
    }

    fts_xml_repr_free(exception_xml, env);
    return exception;
}

void _fts_exception_free_NotExistsException(fts_exception_t *self)
{
    assert(self);
    const axutil_env_t *env = fts_exception_get_env(self);
    assert(env);
    
    if (self && env) {
        adb_NotExistsException_t* obj = (adb_NotExistsException_t*)(fts_exception_get_object(self));
        adb_NotExistsException_free(obj, env);
    }
}

const char* _fts_exception_get_message_NotExistsException(const fts_exception_t *self)
{
    assert(self);
    const axutil_env_t *env = fts_exception_get_env(self);
    adb_NotExistsException_t* obj = (adb_NotExistsException_t*)(fts_exception_get_object(self));
    assert(env);
    assert(obj);
    const char* message = NULL;
    
    if (self && obj && env) {
        adb_TNotExistsException_t* real_object = adb_NotExistsException_get_NotExistsException(obj, env);
        assert(real_object);
        
        if (real_object && 
            !adb_TNotExistsException_is_message_nil(real_object, env))
        {
            message = adb_TNotExistsException_get_message(real_object, env);
        }
    }

    return message;    
}

const char* _fts_exception_get_name_NotExistsException(void)
{
    return "NotExistsException";
}

