/*
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://www.eu-egee.org/partners/ for details on the copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *  gLite Data Management - Simple channel management API
 *
 *  Authors:
 *      Zsolt Molnar <Zsolt.Molnar@cern.ch>
 */

#include <stdlib.h>

#include "fts_xml_repr.h"

struct fts_xml_repr
{
	axiom_node_t *node;
	axiom_element_t *element;
};

fts_xml_repr_t* fts_xml_repr_create(axiom_node_t *node, axiom_element_t *element)
{
	fts_xml_repr_t* self = calloc(1, sizeof(fts_xml_repr_t));
	assert(self);

	if (self) {
		self->node = node;
		self->element = element;
	}

	return self;
}

void fts_xml_repr_free(fts_xml_repr_t* self, const axutil_env_t* env)
{
	if (self) {
		axiom_node_free_tree(self->node, env);
		free(self);
	}
}

axiom_node_t* fts_xml_repr_node(fts_xml_repr_t* self)
{
	assert(self);
	return self ? self->node : NULL;
}

axiom_node_t** fts_xml_repr_node_ref(fts_xml_repr_t* self)
{
	assert(self);
	/* Here, self MUST not be null... */
	return &self->node;
}

axiom_element_t* fts_xml_repr_element(fts_xml_repr_t* self)
{
	assert(self);
	return self ? self->element : NULL;
}

int fts_xml_repr_is_valid(fts_xml_repr_t* self)
{
	return self && self->node && self->element;
}
