/*
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://www.eu-egee.org/partners/ for details on the copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *  gLite Data Management - Simple channel management API
 *
 *  Authors:
 *      Zsolt Molnar <Zsolt.Molnar@cern.ch>
 */

#ifndef FTS_XML_REPR_H
#define FTS_XML_REPR_H

#include <stdio.h>
#include <assert.h>

#include <axiom_node.h>
#include <axiom_element.h>

/**
 * An AXIOM node/element pair representing an XML subtree. We refer to this structure
 * as "FTS representation" of an XML tree.
 */
typedef struct fts_xml_repr fts_xml_repr_t;

/**
 * Create an fts_xml_repr object.
 */
fts_xml_repr_t* fts_xml_repr_create(axiom_node_t *node, axiom_element_t *element);

/**
 * Free an fts_xml_repr object.
 * @param self The object to be freed
 * @param env The present AXIS environment.
 */
void fts_xml_repr_free(fts_xml_repr_t* self, const axutil_env_t* env);

/**
 * Get the AXIOM node
 */
axiom_node_t* fts_xml_repr_node(fts_xml_repr_t* self);

/**
 * Get the AXIOM node by reference
 */
axiom_node_t** fts_xml_repr_node_ref(fts_xml_repr_t* self);

/**
 * Get the AXIOM element representation
 */
axiom_element_t* fts_xml_repr_element(fts_xml_repr_t* self);

/*
 * Check if the internal state of the fts_xml_repr object is valid.
 */
int fts_xml_repr_is_valid(fts_xml_repr_t* obj);

#endif /* #define FTS_XML_REPR_H */
