/*
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://www.eu-egee.org/partners/ for details on the copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
 
#ifndef TRANSFER_API_INTERNAL_H
#define TRANSFER_API_INTERNAL_H

#include <glib.h>

#ifndef G_GNUC_INTERNAL
#if __GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 3)
#define G_GNUC_INTERNAL __attribute__((__visibility__("hidden")))
#else
#define G_GNUC_INTERNAL
#endif /* __GNUC__ */
#endif /* !G_GNUC_INTERNAL */

/**********************************************************************
 * Constants
 */

#define HTTP_PREFIX         "http://"
#define HTTPS_PREFIX            "https://"
#define HTTPG_PREFIX            "httpg://"

typedef enum
{
    PORT_NONE,
    PORT_CHANNEL,
    PORT_FTS,
    PORT_TRANSFERSTATS
} transfer_port;


/**********************************************************************
 * Data type definitions
 */

struct _glite_transfer_ctx
{
    char                *last_error;
    glite_transfer_errclass     errclass;

    struct soap         *soap;
    char                *default_endpoint;
    char                *endpoint;

    char                *source;
    char                *destination;

    transfer_port           port_type;
    void                *priv;
    void                (*cleanup)(glite_transfer_ctx *ctx);
};


/**********************************************************************
 * Inline helper functions
 */

#define STRING_TO_SOAP(x, f) \
    do { \
        s ## x->f = soap_strdup(soap, x->f); \
        if (x->f && ! s ## x->f) \
            return NULL; \
    } while (0)
#define NUM_TO_SOAP(x, f) \
    s ## x->f = x->f

#define STRING_FROM_SOAP(x, f) \
    x->f = g_strdup(s ## x->f)
#define NUM_FROM_SOAP(x, f) \
    x->f = s ## x->f
#define OPT_NUM_FROM_SOAP(x, f, d) \
   x->f = (0 != s ## x->f)?(*(s ## x->f)):(d)

static inline void err_outofmemory(glite_transfer_ctx *ctx)
{
    glite_transfer_set_error(ctx, GLITE_TRANSFER_ERROR_OUTOFMEMORY,
        "Out of memory");
}

static inline void err_invarg(glite_transfer_ctx *ctx, const char *msg, ...)
{
    va_list ap;

    va_start(ap, msg);
    glite_transfer_set_verror(ctx, GLITE_TRANSFER_ERROR_INVALIDARGUMENT, msg, ap);
    va_end(ap);
}

static inline void err_soap(glite_transfer_ctx *ctx, const char *msg, ...)
{
    va_list ap;

    va_start(ap, msg);
    glite_transfer_set_verror(ctx, GLITE_TRANSFER_ERROR_SOAP, msg, ap);
    va_end(ap);
}

#endif /* TRANSFER_API_INTERNAL_H */
