/*
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://www.eu-egee.org/partners/ for details on the copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *  gLite Transfer Clients - Sets the transfer limit of a VO on a given channel
 *
 */

#include <glite/data/transfer/c/channel-simple.h>

#include <stdio.h>
#include <stdlib.h>

#include "tool-main.h"

/**********************************************************************
 * Global variables
 */

/* Usage message */
const char *tool_usage = "CHANNEL VONAME TRANSFER_LIMIT";

/* Help message */
const char *tool_help = NULL;

/* getguid-specific command line options */
const char *tool_options = NULL;
NO_TOOL_LONG_OPTIONS;

/**********************************************************************
 * Tool implementation
 */

int tool_doit(glite_transfer_ctx *ctx, int argc, char *argv[]) {
    int limit, ret;

    if (argc != 3) {
        error("Wrong number of arguments");
        return EXIT_FAILURE;
    }

    if (!sscanf(argv[2], "%d", &limit)) {
        error("Unable to parse TRANSFER_LIMIT argument");
        return EXIT_FAILURE;
    }

    ret = glite_channel_setVOLimit(ctx, argv[0], argv[1], limit);

    if (ret) {
        error("setVOLimit: %s", glite_transfer_get_error(ctx));
        return EXIT_FAILURE;
    }

    info("Transfer limit for VO %s on channel %s set to %d", argv[1], argv[0], limit);

    return EXIT_SUCCESS;
}

/**********************************************************************
 * Command line parsing
 */

int tool_parse_cmdline(int c G_GNUC_UNUSED, char * opt_arg G_GNUC_UNUSED) {
    return -1;
}
