/*
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://www.eu-egee.org/partners/ for details on the copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *  gLite Transfer Clients - Get roles of the client on the service
 *
 *  Authors: Zoltán Farkas <Zoltan.Farkas@cern.ch>
 *
 */

#include <glite/data/transfer/c/fts-simple.h>

#include <stdio.h>
#include <stdlib.h>

#include "tool-main.h"

/**********************************************************************
 * Global variables
 */

/* Usage message */
const char *tool_usage = NULL;

/* Help message */
const char *tool_help =
"  -u DN                        Get roles for specified DN\n";

/* getguid-specific command line options */
const char *tool_options = "u:";
NO_TOOL_LONG_OPTIONS;

/* DN of the other user to get informastion about, if it's not you */
char * otherDN = NULL;

/**********************************************************************
 * Tool implementation
 */

int tool_doit(glite_transfer_ctx *ctx, int argc G_GNUC_UNUSED, char *argv[] G_GNUC_UNUSED) {
    int i;
    glite_transfer_Roles *roles;

    if ( (otherDN != NULL) && (!isRolesOfSupported()) ) {
        error("The server you are contacting does not support the -u option of getroles (it is running interface version %s).", srv_iface_ver);
        return EXIT_FAILURE;
    }

    if (otherDN != NULL) {
        roles = glite_fts_getRolesOf(ctx, otherDN);
    } else {
        roles = glite_fts_getRoles(ctx);
    }
    if (!roles) {
        error("getRoles: %s", glite_transfer_get_error(ctx));
        return EXIT_FAILURE;
    }

    if (otherDN == NULL) {
        printf("Your current clientDN is: %s\n\n", roles->clientDN);
        if (roles->serviceAdmin!=NULL) {
            printf("You are authorised as Service Admin because your cert contains the following principal: %s\n\n", roles->serviceAdmin);
        }
        if (roles->submitter==NULL) {
            printf("You are not authorised to submit to this service.\n\n");
        } else {
            printf("You are authorised to submit to this service because your cert contains the following principal: %s\n\n", roles->submitter);
        }
        printf("You are VO manager for %d VOs.\n", roles->__sizeVOManager);
        for (i = 0; i < roles->__sizeVOManager; i++) {
            printf("You are VO manager for VO <%s> because your cert contains the following principal: %s\n",
                   roles->VOManager[i]->string1, roles->VOManager[i]->string2);
        }

        printf("\nYou are channel manager for %d channels.\n", roles->__sizechannelManager);

        for (i = 0; i < roles->__sizechannelManager; i++) {
            printf("You are channel manager for channel <%s> because your cert contains the following principal: %s\n",
                   roles->channelManager[i]->string1, roles->channelManager[i]->string2);
        }
    } else {
        printf("The DN of the user you are checking is: %s\n\n", roles->clientDN);
        if (roles->serviceAdmin==NULL) {
            printf("This user is not authorised as Service Admin.\n\n");
        } else {
            printf("This user is authorised as Service Admin.\n\n");
        }
        if (roles->submitter==NULL) {
            printf("The user is not authorised to submit to the service.\n\n");
        } else {
            printf("The user is authorised to submit to the service.\n\n");
        }
        printf("The user is VO manager for %d VOs.\n", roles->__sizeVOManager);
        for (i = 0; i < roles->__sizeVOManager; i++) {
            printf("The user is VO manager for VO <%s>\n",
                   roles->VOManager[i]->string1);
        }

        printf("\nThe user is channel manager for %d channels.\n", roles->__sizechannelManager);

        for (i = 0; i < roles->__sizechannelManager; i++) {
            printf("The user is channel manager for channel <%s>\n",
                   roles->channelManager[i]->string1);
        }

    }

    return EXIT_SUCCESS;
}

/**********************************************************************
 * Command line parsing
 */

int tool_parse_cmdline(int c, char *opt_arg) {
    switch (c) {
    case 'u':
        otherDN = opt_arg;
        return 0;
    default:
        break;
    }
    return -1;
}
