/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004-2008.
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  list groups utility
 *
 *  Authors: Paolo Tedesco <paolo.tedesco@cern.ch>
 *  Version info: $Id: group-list.c,v 1.4 2009/07/02 15:28:18 szamsu Exp $
 *  Release: $Name:  $
 *
 */
#include <glite/data/transfer/c/channel-simple.h>
#include <stdlib.h>
#include <stdio.h>
#include "tool-main.h"

// Usage message
const char *tool_usage = "[GROUP ...]";

// extended information flag (also list members)
int extended_list = 0;

// Help text
const char *tool_help =
    "  -x                           Extended information (list members)\n"
    ;
NO_TOOL_LONG_OPTIONS;

// command line options
const char *tool_options = "x";

// command line parsing
int tool_parse_cmdline(int c G_GNUC_UNUSED, char *opt_arg G_GNUC_UNUSED) {
    switch (c) {
    case 'x':
        extended_list = 1;
        return 0;
    default:
        break;
    }
    return -1;
}

// actual execution
int tool_doit(glite_transfer_ctx *ctx, int argc, char *argv[]) {
    char ** groupNames = 0;
    int groupCount = 0;
    if (0 == argc){
        // no group names provided; get list from service
        groupNames = glite_channel_getSiteGroupNames(ctx,&groupCount);
        if (NULL == groupNames) {
            error("getSiteGroupNames: %s", glite_transfer_get_error(ctx));
            return EXIT_FAILURE;
        }
    } else {
        // group names specified on the command line; assume -x
        extended_list = 1;
        groupNames = argv;
        groupCount = argc;
    }
    int ret = EXIT_SUCCESS;
    // for each group in the list, print name and details
    int i = 0;
    for (;i < groupCount;++i){
        char * group_name = validateGroupName(groupNames[i]);
        printf("\n%s\n",group_name);
        if (extended_list){
            // get and display group members
            char ** groupMembers = 0;
            int membersCount = 0;
            groupMembers = glite_channel_getSiteGroupMembers(ctx,group_name,&membersCount);
            if (NULL == groupMembers){
                error("Failed listing group members for group '%s': %s\n",group_name,glite_transfer_get_error(ctx));
                ret = EXIT_FAILURE;
                free (group_name);
                continue;
            }
            if (0 == membersCount){
                printf("  Group is empty\n");
            }
            else {
                printf("  Members:\n");
                int j = 0;
                for (;j < membersCount;++j){
                    printf("    %s\n",groupMembers[j]);
                }
            }
            free (group_name);
        }
    }
    return ret;
}
