/*
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://www.eu-egee.org/partners/ for details on the copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *  gLite Transfer Clients - List transfer requests
 *
 *  Authors: Gabor Gombas <Gabor.Gombas@cern.ch>
 *  Version info: $Id: list-transfer.c,v 1.17 2008/08/13 14:44:52 ptedesco Exp $
 *
 */

#include <glite/data/transfer/c/fts-simple.h>
#include <glite/data/glite-util.h>

#include <unistd.h>
#include <stdlib.h>
#include <string.h>
#include <stdio.h>

#include "tool-main.h"

/**********************************************************************
 * Global variables
 */

/* Usage message */
const char *tool_usage = "[STATE...]";

/* Help message */
const char *tool_help =
"  -c CHANNEL                   Channel name to match\n"
"  -u USERDN                    Restrict to specific user DN\n"
"  -o VONAME                    Restrict to specific VO\n";

/* getguid-specific command line options */
const char *tool_options = "c:u:o:";
NO_TOOL_LONG_OPTIONS;

/* Channel name */
static char *channel = NULL;

/* Restrict VO */
static char* restrict_vo = NULL;

/* Restrict userDN */
static char* restrict_dn = NULL;

/**********************************************************************
 * Tool implementation
 */

int tool_doit(glite_transfer_ctx *ctx, int argc, char *argv[]) {
    glite_transfer_JobStatus **list;
    int i, cnt;
    char *action_states_withReady[4] = {
        (char *)glite_transfer_state_str(GLITE_TRANSFER_SUBMITTED),
        (char *)glite_transfer_state_str(GLITE_TRANSFER_PENDING),
        (char *)glite_transfer_state_str(GLITE_TRANSFER_READY),
        (char *)glite_transfer_state_str(GLITE_TRANSFER_ACTIVE)
    };

    char *action_states_withoutReady[3] = {
        (char *)glite_transfer_state_str(GLITE_TRANSFER_SUBMITTED),
        (char *)glite_transfer_state_str(GLITE_TRANSFER_PENDING),
        (char *)glite_transfer_state_str(GLITE_TRANSFER_ACTIVE)
    };

    if ( restrict_dn && !isUserVoRestrictListingSupported()) {
        error("The server you are contacting does not support the -u option (it is running interface version %s).", srv_iface_ver);
        return EXIT_FAILURE;
    }
    if ( restrict_vo && !isUserVoRestrictListingSupported()) {
        error("The server you are contacting does not support the -o option (it is running interface version %s).", srv_iface_ver);
        return EXIT_FAILURE;
    }

    if ( isUserVoRestrictListingSupported() ) { // call listRequests2

        if(argc==0)
            list = glite_fts_listRequests2(ctx, 4, (const char**)action_states_withReady,
                                           channel, restrict_dn, restrict_vo, &cnt);
        else
            list = glite_fts_listRequests2(ctx, argc, (const char**)argv,
                                           channel, restrict_dn, restrict_vo, &cnt);

    } else { // call listRequests

        if(argc==0)
            list = glite_fts_listRequests(ctx, 3, (const char**)action_states_withoutReady,
                                          channel, &cnt);
        else
            list = glite_fts_listRequests(ctx, argc, (const char**)argv,
                                          channel, &cnt);
    }

    if (cnt < 0) {
        error("list: %s", glite_transfer_get_error(ctx));
        return EXIT_FAILURE;
    }

    for (i = 0; i < cnt; i++) {
        if(verbose_output) {
            char buf[64];
            struct tm tm;

            localtime_r(&list[i]->submitTime.tv_sec, &tm);
            strftime(buf, sizeof(buf), "%Y-%m-%d %H:%M:%S", &tm);

            if (i)
                printf("\n");

            printf("Request ID:\t%s\n", list[i]->jobId);
            print_job(list[i]);
        } else {
            printf("%s\t%s\n", list[i]->jobId, glite_transfer_state_str(list[i]->jobStatus));
        }
    }

    glite_transfer_JobStatus_freeArray(ctx, cnt, list);
    return EXIT_SUCCESS;
}

/**********************************************************************
 * Command line parsing
 */

int tool_parse_cmdline(int c, char *opt_arg) {
    switch (c) {
    case 'c':
        channel = opt_arg;
        return 0;
    case 'o':
        restrict_vo = opt_arg;
        return 0;
    case 'u':
        restrict_dn = opt_arg;
        return 0;
    default:
        break;
    }
    return -1;
}
