/*
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://www.eu-egee.org/partners/ for details on the copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *  gLite Transfer Clients - Set priority of a job.
 *
 *  Authors: Zoltán Farkas <Zoltan.Farkas@cern.ch>
 *
 */

#include <glite/data/transfer/c/fts-simple.h>

#include <stdio.h>
#include <stdlib.h>

#include "tool-main.h"

/**********************************************************************
 * Global variables
 */

/* Usage message */
const char *tool_usage = "ID PRIORITY\n"
"  ID:                          id of the job\n"
"  PRIORITY:                    the priority to set, in range [0 (lower) -\n"
"                               5 (higher)]. Default priority is 3.\n";

/* Help message */
const char *tool_help = NULL;

/* getguid-specific command line options */
const char *tool_options = NULL;
NO_TOOL_LONG_OPTIONS;

/**********************************************************************
 * Tool implementation
 */

int tool_doit(glite_transfer_ctx *ctx, int argc, char *argv[]) {
    int ret, prio;

    if (argc != 2) {
        error("Wrong number of arguments");
        return EXIT_FAILURE;
    }

    if (!sscanf(argv[1], "%d", &prio)) {
        error("Unable to parse PRIORITY argument");
        return EXIT_FAILURE;
    }

    ret = glite_fts_setJobPriority(ctx, argv[0], prio);
    if (ret) {
        error("setPriority: %s", glite_transfer_get_error(ctx));
        return EXIT_FAILURE;
    }
    info("Priority of job %s set to %d", argv[0], prio);

    return EXIT_SUCCESS;
}

/**********************************************************************
 * Command line parsing
 */

int tool_parse_cmdline(int c G_GNUC_UNUSED, char * optarg G_GNUC_UNUSED) {
    return -1;
}
