/*
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://www.eu-egee.org/partners/ for details on the copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *  gLite Transfer Clients - Signal held jobs
 *
 *  Authors: Gabor Gombas <Gabor.Gombas@cern.ch>
 *  Version info: $Id: signal.c,v 1.7 2008/11/27 14:06:32 ptedesco Exp $
 *  Release: $Name:  $
 *
 *  Revision history:
 *  $Log: signal.c,v $
 *  Revision 1.7  2008/11/27 14:06:32  ptedesco
 *  updated channel set command
 *
 *  Revision 1.6  2008/11/26 08:57:59  ptedesco
 *  added listing for Channel3 objects
 *
 *  Revision 1.5  2008/08/13 14:44:52  ptedesco
 *  fixed bug #40064, refactored options parsing, modified help messages
 *
 *  Revision 1.4  2008/05/08 15:03:48  ptedesco
 *  Fix bug #33406
 *
 *  Revision 1.3  2006/12/06 15:40:08  mccance
 *  Bug 20671: list states
 *
 *  Revision 1.2  2005/04/06 16:29:10  gombasg
 *  Updates for transfer API 2.9.0
 *
 *  Revision 1.1  2005/03/29 15:14:00  gombasg
 *  New tool: glite-transfer-channel-signal
 *
 *
 */

#include <glite/data/transfer/c/channel-simple.h>

#include <stdlib.h>

#include "tool-main.h"

/**********************************************************************
 * Global variables
 */

/* Usage message */
const char *tool_usage = "STATE [Cancel, Pending, Failed]";

/* Help message */
const char *tool_help = 
"  -c CHANNEL                   Specify the channel name\n"
"  -j JOBID                     Specify the job ID\n";

/* getguid-specific command line options */
const char *tool_options = "c:j:";
NO_TOOL_LONG_OPTIONS;

/* Channel name */
static char *channel;

/* Job ID */
static char *job_id;


/**********************************************************************
 * Tool implementation
 */

int tool_doit(glite_transfer_ctx *ctx, int argc, char *argv[])
{
    glite_transfer_state state;
    int ret;

    if (!argc)
    {
        error("New job state is not specified");
        return EXIT_FAILURE;
    }

    if (!(!!channel ^ !!job_id))
    {
        error("Exactly one of the -c and -j options must be given");
        return EXIT_FAILURE;
    }

    state = glite_transfer_state_parse(ctx, argv[0]);
    if (state == GLITE_TRANSFER_UNKNOWN)
    {
        error("Unknown transfer state: %s", argv[0]);
        return EXIT_FAILURE;
    }

    if (job_id)
        ret = glite_channel_changeStateForHeldJob(ctx, job_id, state);
    else
        ret = glite_channel_changeStateForHeldJobsOnChannel(ctx, channel, state);
    if (ret)
    {
        error("signal: %s", glite_transfer_get_error(ctx));
        return EXIT_FAILURE;
    }
    info("Modified %s %s", channel ? "channel" : "job",
        channel ? channel : job_id);

    return EXIT_SUCCESS;
}

/**********************************************************************
 * Command line parsing
 */

int tool_parse_cmdline(int c, char *opt_arg)
{
    switch (c)
    {
        case 'c':
            channel = opt_arg;
            return 0;
        case 'j':
            job_id = opt_arg;
            return 0;
        default:
            break;
    }
    return -1;
}
