/**
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://www.eu-egee.org/partners/ for details on the copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *  gLite Transfer Clients - Main function for the tools
 *
 *  Authors: Gabor Gombas <Gabor.Gombas@cern.ch>
 *           Paolo Tedesco <paolo.tedesco@cern.ch>
 *  Version info: $Id: tool-main.h,v 1.17 2009/07/02 15:28:18 szamsu Exp $
 *  Release: $Name:  $
 */

#ifndef TOOL_MAIN_H
#define TOOL_MAIN_H

#include <glib.h>

// command line options handling
#include <getopt.h>
// Use these macros in option structure for long options not using a 
// short argument. If a letter is used, the 'tool_parse_cmdline' 
// function will not get the possibility to parse it. (see bug#40064) 
// These macros just ensures that the code is mapped to a non-printable
// character.
#define MAIN_OPT_NUM(x) (x + 0x80)
#define TOOL_OPT_NUM(x) (x + 0xA0)

/**********************************************************************
 * Constants
 */


/**********************************************************************
 * Data type definitions
 */


/**********************************************************************
 * Prototypes
 */

/* Parse tool-specific command line option */
int tool_parse_cmdline(int option, char *opt_arg);

/* Perform tool operation */
int tool_doit(glite_transfer_ctx *ctx, int argc, char *argv[]);

/**********************************************************************
 * Utility functions
 */

#ifdef __GNUC__
#define PRINTF(string_index,first_to_check) __attribute__((format (printf, string_index, first_to_check)))
#else
#define PRINTF(string_index,first_to_check)
#endif
 
/* Print a debug message (if compiled with _DEBUG) */
void debug(const char *fmt, ...) PRINTF(1,2);
 
/* Print an informational message */
void info(const char *fmt, ...) PRINTF(1,2);

/* Print an error message */
void error(const char *fmt, ...) PRINTF(1,2);

void print_job(const glite_transfer_JobStatus *job);

/* Check if checksum is supporter or not, using interface version */
int isChecksumSupported(void);

/* Check if delegation is supported on not, using interface version */
int isDelegationSupported(void);

/* Check if delegation is supported on not, using interface version */
int isRolesOfSupported(void);

/* Check if setting TCP buffer size is supported on not, using interface version */
int isSetTCPBufferSupported(void);

/* Check if extended listing is supported (Channel2 objects) */
int isExtendedChannelListSupported(void);

/* Check if channel message is supported */
int isChannelMessageSupported(void);

/* Check if userDN and VO restiection is supported on listTransfers operation */
int isUserVoRestrictListingSupported(void);

/* Check if the FTS version 3.3.0 extra states are supported */
int isVersion330StatesSupported(void);

/* Internal: check if it is version >= 3.3.0 */
int isItVersion330(void);

/* Check if the FTS version 3.4.0 extra features are supported */
int isItVersion340(void);

/* Check if the FTS version 3.5.0 extra features are supported */
int isItVersion350(void);

/* Check if the FTS version 3.7.0 extra features are supported */
int isItVersion370(void);

/* Validate a group name */
char * validateGroupName(const char * name);

/**********************************************************************
 * Global variables exported by the tool
 */

/* Tool-specific command line options */
extern const char *tool_options;
extern struct option tool_long_options[];
extern int tool_long_options_size;

#define NO_TOOL_LONG_OPTIONS \
    struct option tool_long_options[] = {}; \
    int tool_long_options_size = 0

#define SET_TOOL_LONG_OPTIONS_SIZE \
    int tool_long_options_size = sizeof(tool_long_options) / sizeof(struct option)
        
/* Tool-specific help message */
extern const char *tool_help;

/* Tool-specific usage instructions */
extern const char *tool_usage;

/**********************************************************************
 * Global variables exported by the main module
 */

/* Verbosity level - for service info */
extern int verbose_flag;

/* Verbosity level - for application output */
extern int verbose_output;

/* Request quiet operation */
extern int quiet_flag;

/* Location of the transfer service */
extern char *service_location;

/* Interface version */
extern char *srv_iface_ver, *srv_iface_ver_major, *srv_iface_ver_minor, *srv_iface_ver_patch;
extern long iface_major, iface_minor, iface_patch;

#endif /* TOOL_MAIN_H */
