/**
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://www.eu-egee.org/partners/ for details on the copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *  gLite Transfer Clients - Utilities
 *
 *  Authors: Gabor Gombas <Gabor.Gombas@cern.ch>
 *           Paolo Tedesco <paolo.tedesco@cern.ch>
 *  Version info: $Id: util.c,v 1.18 2009/07/02 15:28:18 szamsu Exp $
 *  Release: $Name:  $
 */

#include <glite/data/transfer/c/transfer-simple.h>

#include <string.h>
#include <stdio.h>

#include "tool-main.h"

/* Interface version */
char *srv_iface_ver, *srv_iface_ver_major, *srv_iface_ver_minor, *srv_iface_ver_patch;
long iface_major, iface_minor, iface_patch;

/**********************************************************************
 * Logging functions
 */

void debug(const char *fmt, ...){
/*
#ifdef _DEBUG    
    va_list ap;
    va_start(ap, fmt);
    fprintf(stderr, "~ ");
    vprintf(fmt, ap);
    fprintf(stderr, "\n");
    fflush(stderr);
    va_end(ap);
#endif    
*/
}
 
void info(const char *fmt, ...){
    va_list ap;

    if (!verbose_flag)
        return;

    va_start(ap, fmt);
    vprintf(fmt, ap);
    printf("\n");
    fflush(stdout);
    va_end(ap);
}

void error(const char *fmt, ...){
    char *p, *msg;
    va_list ap;

    if (quiet_flag)
        return;

    va_start(ap, fmt);
    msg = g_strdup_vprintf(fmt, ap);
    va_end(ap);

    // If the command name is the same as the name of the failed method,
    // we may get duplication at the beginning of the message, like
    // mv: mv: Destination entry: "/foo" already exists!
    // Remove the duplication. 
    p = strchr(msg, ':');
    if (p){
        int len = p - msg + 1;
        if (msg[len + 1] && !strncmp(msg, msg + len + 1, len))
            memmove(msg, msg + len + 1, strlen(msg) - len);
    }
    fprintf(stderr, "%s\n", msg);
    fflush(stderr);
    g_free(msg);
}


/**********************************************************************
 * Utility functions
 */

void print_job(const glite_transfer_JobStatus *job) {
    char buf[64];
    struct tm tm;

    localtime_r(&job->submitTime.tv_sec, &tm);
    strftime(buf, sizeof(buf), "%Y-%m-%d %H:%M:%S", &tm);

    printf("Status:\t\t%s\n",
           glite_transfer_state_str(job->jobStatus));
    printf("Channel:\t%s\n",
           job->channelName ?  job->channelName : "<None>");
    printf("Client DN:\t%s\n", job->clientDN);
    printf("Reason:\t\t%s\n", job->reason ?  job->reason : "<None>");
    printf("Submit time:\t%s.%03ld\n", buf,
           job->submitTime.tv_nsec / 1000000);
    printf("Files:\t\t%d\n", job->numFiles);
    printf("Priority:\t%d\n", job->priority);
    printf("VOName:\t\t%s\n", job->voName);
}

int isChecksumSupported() {
    return isItVersion370();
}

int isDelegationSupported() {
    return isItVersion330();
}

int isRolesOfSupported() {
    return isItVersion330();
}

int isSetTCPBufferSupported() {
    return isItVersion330();
}

int isExtendedChannelListSupported() {
    return isItVersion330();
}

int isChannelMessageSupported() {
    return isItVersion330();
}

int isUserVoRestrictListingSupported() {
    return isItVersion330();
}

int isVersion330StatesSupported(){
    return isItVersion330();
}

int isItVersion330() {
    if (iface_major >= 3 && iface_minor >= 3 && iface_patch >= 0 )
        return 1;
    else
        return 0;
}

int isItVersion340() {
    if (iface_major >= 3 && iface_minor >= 4 && iface_patch >= 0 )
        return 1;
    else
        return 0;
}

int isItVersion350() {
    if (iface_major >= 3 && iface_minor >= 5 && iface_patch >= 0 )
        return 1;
    else
        return 0;
}

int isItVersion370() {
    if (iface_major >= 3 && iface_minor >= 7 && iface_patch >= 0 )
        return 1;
    else
        return 0;
}

/* Validate a group name */
char * validateGroupName(const char * name){
    int len = strlen(name);
    char * ret = malloc((len + 3) * sizeof(char));
    int pos = 0;
    if ('[' != name[0]){
        ret[0] = '[';
        pos = 1;
    }
    memcpy(ret + pos,name,len);
    pos += len;
    if (']' != name[len - 1]){
        ret[pos] = ']';
        ++pos;
    }
    ret[pos] = 0;
    return ret;
}
