#!/bin/bash
#
# Copyright (c) Members of the EGEE Collaboration. 2004.
# See http://www.eu-egee.org/partners/ for details on the copyright holders.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Authors: 
#      Akos Frohner <Akos.Frohner@cern.ch>
#

TEST_MODULE='org.glite.data.transfer-cli'
TEST_REQUIRES='glite-transfer-submit glite-transfer-status glite-transfer-cancel'

if [ -z "$GLITE_LOCATION" ]; then
    GLITE_LOCATION=$(dirname $0)/../../stage
fi
source $GLITE_LOCATION/share/test/utils/shunit


TEST_CERT_DIR=$GLITE_LOCATION/share/test/certificates
if [ ! -d "$TEST_CERT_DIR" ]; then
    echo "Error: Certificates directory '$TEST_CERT_DIR' was not found!" >&2
    exit -1
fi

export X509_CERT_DIR=$TEST_CERT_DIR/grid-security/certificates
export X509_VOMS_DIR=$TEST_CERT_DIR/grid-security/vomsdir
export X509_USER_PROXY=$TEST_CERT_DIR/home/user01-voms.pem

if [ 'yes' = "$TEST_VERBOSE" ]; then
    echo "#Info: the test is using the following credentials:"
    echo "  export X509_USER_PROXY=$X509_USER_PROXY"
    echo "  export X509_CERT_DIR=$X509_CERT_DIR"
    echo "  export X509_VOMS_DIR=$X509_VOMS_DIR"
    echo ""
fi

export GLITE_SD_VO='org.acme'
export GLITE_SD_PLUGIN='file'
export GLITE_SD_SERVICES_XML=$(dirname $0)/services.xml

if [ 'yes' = "$TEST_VERBOSE" ]; then
    echo "#Info: the test is using the following service-discovery settings:"
    echo "  export GLITE_SD_VO='$GLITE_SD_VO'"
    echo "  export GLITE_SD_PLUGIN='$GLITE_SD_PLUGIN'"
    echo "  export GLITE_SD_SERVICES_XML=$GLITE_SD_SERVICES_XML"
fi

test_success 'Endpoint: http.*://localhost:8.*/glite-data-transfer-fts' \
    glite-sd-query -t org.glite.FileTransfer

echo ""
echo " Single-file job"
echo ""

test_success 'Using endpoint' \
    glite-transfer-submit -v srm://a.example.org/a srm://b.example.org/b
jobid=$(tail -1 $tempbase.stdout)
test_success '........-....-....-....-............' \
    echo "$jobid"

test_success 'Destination: srm://b.example.org/b' \
    glite-transfer-status -l --verbose $jobid

test_success "Canceled $jobid" \
    glite-transfer-cancel -v $jobid

echo ""
echo " Multi-file job"
echo ""

cat >$tempbase.job <<EOF
srm://a.example.org/1 srm://b.example.org/1
srm://a.example.org/2 srm://b.example.org/2
srm://a.example.org/3 srm://b.example.org/3
EOF

test_success 'Using endpoint' \
    glite-transfer-submit -v -f $tempbase.job
jobid=$(tail -1 $tempbase.stdout)
jobid=$(tail -1 $tempbase.stdout)
test_success '........-....-....-....-............' \
    echo "$jobid"

test_success 'Destination: srm://b.example.org/3' \
    glite-transfer-status -l --verbose $jobid

test_success "Canceled $jobid" \
    glite-transfer-cancel -v $jobid

test_summary
